@@ -2,11 +2,13 @@ package org.videolan.medialibrary;
 
 import android.Manifest;
 import android.content.Context;
+import android.content.Intent;
 import android.content.pm.PackageManager;
 import android.net.Uri;
 import android.os.Build;
 import android.os.Environment;
 import android.support.v4.content.ContextCompat;
+import android.support.v4.content.LocalBroadcastManager;
 import android.text.TextUtils;
 import android.util.Log;
 
@@ -41,13 +43,18 @@ public class Medialibrary {
     public static final int FLAG_MEDIA_ADDED_VIDEO          = 1 << 5;
 
     private static final String extDirPath = Environment.getExternalStorageDirectory().getAbsolutePath();
+    public static final String ACTION_IDLE = "action_idle";
+    public static final String STATE_IDLE = "state_idle";
 
     private static final MediaWrapper[] EMPTY_COLLECTION = {};
     public static final String VLC_MEDIA_DB_NAME = "/vlc_media.db";
     public static final String THUMBS_FOLDER_NAME = "/thumbs";
 
+    private Context mContext;
+
     private long mInstanceID;
     private volatile boolean mIsInitiated = false;
+    private boolean mIsWorking = false;
 
     private MediaUpdatedCb mediaUpdatedCb = null;
     private MediaAddedCb mediaAddedCb = null;
@@ -65,10 +72,6 @@ public class Medialibrary {
         System.loadLibrary("mla");
     }
 
-    public void setup() {
-        nativeSetup();
-    }
-
     public boolean init(Context context) {
         mIsInitiated = nativeInit(context.getCacheDir()+ VLC_MEDIA_DB_NAME, context.getExternalFilesDir(null).getAbsolutePath()+ THUMBS_FOLDER_NAME);
         return mIsInitiated;
@@ -87,8 +90,8 @@ public class Medialibrary {
         return mIsInitiated ? nativeDevices() : new String[0];
     }
 
-    public boolean addDevice(String uuid, String path, boolean removable) {
-        return nativeAddDevice(uuid, Tools.encodeVLCMrl(path), removable);
+    public boolean addDevice(String uuid, String path, boolean removable, boolean notify) {
+        return nativeAddDevice(uuid, Tools.encodeVLCMrl(path), removable, notify);
     }
 
     public void discover(String path) {
@@ -118,9 +121,11 @@ public class Medialibrary {
         super.finalize();
     }
 
-    public static synchronized Medialibrary getInstance() {
-        if (sInstance == null)
+    public static synchronized Medialibrary getInstance(Context context) {
+        if (sInstance == null) {
             sInstance = new Medialibrary();
+            sInstance.mContext = context;
+        }
         return sInstance;
     }
 
@@ -242,7 +247,7 @@ public class Medialibrary {
     }
 
     public boolean isWorking() {
-        return !mIsInitiated || nativeIsWorking();
+        return mIsWorking;
     }
 
     public boolean isInitiated() {
@@ -359,6 +364,11 @@ public class Medialibrary {
         }
     }
 
+    public void onBackgroundTasksIdleChanged(boolean isIdle) {
+        LocalBroadcastManager.getInstance(mContext).sendBroadcast(new Intent(ACTION_IDLE).putExtra(STATE_IDLE, isIdle));
+        mIsWorking = !isIdle;
+    }
+
     void onReloadStarted(String entryPoint) {
         synchronized (devicesDiscoveryCbList) {
             if (!devicesDiscoveryCbList.isEmpty())
@@ -538,12 +548,11 @@ public class Medialibrary {
 
 
     // Native methods
-    private native void nativeSetup();
     private native boolean nativeInit(String dbPath, String thumbsPath);
     private native void nativeStart();
     private native void nativeRelease();
     private native void nativeBanFolder(String path);
-    private native boolean nativeAddDevice(String uuid, String path, boolean removable);
+    private native boolean nativeAddDevice(String uuid, String path, boolean removable, boolean notify);
     private native String[] nativeDevices();
     private native void nativeDiscover(String path);
     private native void nativeRemoveEntryPoint(String path);
@@ -561,7 +570,6 @@ public class Medialibrary {
     private native MediaWrapper[] nativeGetRecentAudio();
     private native int nativeGetVideoCount();
     private native int nativeGetAudioCount();
-    private native  boolean nativeIsWorking();
     private native Album[] nativeGetAlbums();
     private native Album nativeGetAlbum(long albumtId);
     private native Artist[] nativeGetArtists();
