@@ -7,6 +7,7 @@ import android.content.BroadcastReceiver;
 import android.content.Context;
 import android.content.Intent;
 import android.content.IntentFilter;
+import android.content.SharedPreferences;
 import android.net.Uri;
 import android.os.Binder;
 import android.os.IBinder;
@@ -15,6 +16,7 @@ import android.support.annotation.Nullable;
 import android.support.v4.app.NotificationCompat;
 import android.support.v4.app.NotificationManagerCompat;
 import android.support.v4.content.LocalBroadcastManager;
+import android.support.v7.preference.PreferenceManager;
 import android.text.TextUtils;
 import android.util.Log;
 
@@ -48,10 +50,13 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
     public final static String ACTION_PAUSE_SCAN = "action_pause_scan";
     public final static String ACTION_SERVICE_STARTED = "action_service_started";
     public final static String ACTION_SERVICE_ENDED = "action_service_ended";
+    public final static String ACTION_PROGRESS = "action_progress";
+    public final static String ACTION_PROGRESS_TEXT = "action_progress_text";
+    public final static String ACTION_PROGRESS_VALUE = "action_progress_value";
     public static final long NOTIFICATION_DELAY = 1000L;
     private PowerManager.WakeLock mWakeLock;
+    private LocalBroadcastManager mLocalBroadcastManager;
 
-    private volatile boolean initOngoing = false;
     private final IBinder mBinder = new LocalBinder();
     private Medialibrary mMedialibrary;
     private int mParsing = 0, mReload = 0;
@@ -61,6 +66,7 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
     private final ThreadPoolExecutor mThreadPool = new ThreadPoolExecutor(1, 1, 30, TimeUnit.SECONDS,
             new LinkedBlockingQueue<Runnable>(), VLCApplication.THREAD_FACTORY);
 
+    boolean mScanPaused = false;
     private BroadcastReceiver mReceiver = new BroadcastReceiver() {
         @Override
         public void onReceive(Context context, Intent intent) {
@@ -68,32 +74,43 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
                 case ACTION_PAUSE_SCAN:
                     if (mWakeLock.isHeld())
                         mWakeLock.release();
+                    mScanPaused = true;
                     mMedialibrary.pauseBackgroundOperations();
                     break;
                 case ACTION_RESUME_SCAN:
                     if (!mWakeLock.isHeld())
                         mWakeLock.acquire();
                     mMedialibrary.resumeBackgroundOperations();
+                    mScanPaused = false;
+                    break;
+                case Medialibrary.ACTION_IDLE:
+                    if (intent.getBooleanExtra(Medialibrary.STATE_IDLE, true)) {
+                        if (!mScanPaused) {
+                            stopSelf();
+                            return;
+                        }
+                    }
+                    synchronized (MediaParsingService.this) {
+                        if (mLastNotificationTime != -1L)
+                            mLastNotificationTime = 0L;
+                    }
+                    showNotification();
                     break;
-                default:
-                    return;
             }
-            synchronized (this) {
-                mLastNotificationTime = 0L;
-            }
-            showNotification();
         }
     };
 
     @Override
     public void onCreate() {
         super.onCreate();
+        mLocalBroadcastManager = LocalBroadcastManager.getInstance(this);
         mMedialibrary = VLCApplication.getMLInstance();
         mMedialibrary.addDeviceDiscoveryCb(MediaParsingService.this);
         IntentFilter filter = new IntentFilter();
         filter.addAction(ACTION_PAUSE_SCAN);
         filter.addAction(ACTION_RESUME_SCAN);
         registerReceiver(mReceiver, filter);
+        mLocalBroadcastManager.registerReceiver(mReceiver, new IntentFilter(Medialibrary.ACTION_IDLE));
         PowerManager pm = (PowerManager) VLCApplication.getAppContext().getSystemService(Context.POWER_SERVICE);
         mWakeLock = pm.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, TAG);
         mWakeLock.acquire();
@@ -107,7 +124,7 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
 
     @Override
     public int onStartCommand(Intent intent, int flags, int startId) {
-        synchronized (this) {
+        synchronized (MediaParsingService.this) {
             if (mLastNotificationTime <= 0L)
                 mLastNotificationTime = System.currentTimeMillis();
         }
@@ -125,7 +142,7 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
                 discoverStorage(intent.getStringExtra(EXTRA_PATH));
                 break;
         }
-        LocalBroadcastManager.getInstance(this).sendBroadcast(new Intent(ACTION_SERVICE_STARTED));
+        mLocalBroadcastManager.sendBroadcast(new Intent(ACTION_SERVICE_STARTED));
         return START_NOT_STICKY;
     }
 
@@ -147,6 +164,7 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
         mThreadPool.execute(new Runnable() {
             @Override
             public void run() {
+                addDeviceIfNeeded(path);
                 mMedialibrary.discover(path);
             }
         });
@@ -160,7 +178,11 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
         for (String storagePath : AndroidDevices.getExternalStorageDirectories()) {
             if (path.startsWith(storagePath)) {
                 String uuid = FileUtils.getFileNameFromPath(path);
-                mMedialibrary.addDevice(uuid, path, true);
+                if (TextUtils.isEmpty(uuid))
+                    uuid = "root";
+                mMedialibrary.addDevice(uuid, path, true, true);
+                for (String folder : Medialibrary.getBlackList())
+                    mMedialibrary.banFolder(path + folder);
             }
         }
     }
@@ -181,22 +203,18 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
             mThreadPool.execute(new Runnable() {
                 @Override
                 public void run() {
-                    initOngoing = true;
                     boolean shouldInit = !(new File(MediaParsingService.this.getCacheDir()+Medialibrary.VLC_MEDIA_DB_NAME).exists());
-                    mMedialibrary.setup();
-                    if (mMedialibrary.init(MediaParsingService.this)) {
+                    if (mMedialibrary.init(VLCApplication.getAppContext())) {
                         List<String> devices = new ArrayList<>();
                         devices.add(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
                         devices.addAll(AndroidDevices.getExternalStorageDirectories());
+                        SharedPreferences sharedPreferences = PreferenceManager.getDefaultSharedPreferences(MediaParsingService.this);
                         for (String device : devices) {
                             boolean isMainStorage = TextUtils.equals(device, AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
-                            boolean isNew = mMedialibrary.addDevice(isMainStorage ? "main-storage" : FileUtils.getFileNameFromPath(device), device, !isMainStorage);
-                            if (isMainStorage) {
-                                if (shouldInit) {
-                                    for (String folder : Medialibrary.getBlackList())
-                                        mMedialibrary.banFolder(device + folder);
-                                }
-                            } else if (isNew) {
+                            String uuid = FileUtils.getFileNameFromPath(device);
+                            boolean isNew = mMedialibrary.addDevice(isMainStorage ? "main-storage" : uuid, device, !isMainStorage, false);
+                            boolean isIgnored = sharedPreferences.getBoolean("ignore_"+ uuid, false);
+                            if (!isMainStorage && isNew && !isIgnored) {
                                     startActivity(new Intent(MediaParsingService.this, DialogActivity.class)
                                             .setAction(DialogActivity.KEY_STORAGE)
                                             .addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
@@ -205,13 +223,16 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
 
                         }
                         mMedialibrary.start();
-                        LocalBroadcastManager.getInstance(MediaParsingService.this).sendBroadcast(new Intent(VLCApplication.ACTION_MEDIALIBRARY_READY));
-                        if (shouldInit)
+                        mLocalBroadcastManager.sendBroadcast(new Intent(VLCApplication.ACTION_MEDIALIBRARY_READY));
+                        if (shouldInit) {
+                            for (String folder : Medialibrary.getBlackList())
+                                mMedialibrary.banFolder(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY + folder);
                             mMedialibrary.discover(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
-                        else if (upgrade)
+                        } else if (upgrade)
                             mMedialibrary.forceParserRetry();
+                        else if (PreferenceManager.getDefaultSharedPreferences(MediaParsingService.this).getBoolean("auto_rescan", true))
+                            reload(null);
                     }
-                    initOngoing = false;
                 }
             });
     }
@@ -219,9 +240,11 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
     private NotificationCompat.Builder builder;
     private boolean wasWorking;
     final StringBuilder sb = new StringBuilder();
+    private final Intent progessIntent = new Intent(ACTION_PROGRESS);
+    private final Intent notificationIntent = new Intent();
     private void showNotification() {
         final long currentTime = System.currentTimeMillis();
-        synchronized (this) {
+        synchronized (MediaParsingService.this) {
             if (mLastNotificationTime == -1L || currentTime-mLastNotificationTime < NOTIFICATION_DELAY)
                 return;
             mLastNotificationTime = currentTime;
@@ -245,22 +268,26 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
                             .setAutoCancel(false)
                             .setOngoing(true);
                 }
-                builder.setContentText(sb.toString());
+                String progressText = sb.toString();
+                builder.setContentText(progressText);
 
-                boolean isWorking = mMedialibrary.isWorking();
-                if (wasWorking != isWorking) {
-                    wasWorking = isWorking;
-                    PendingIntent pi = PendingIntent.getBroadcast(MediaParsingService.this, 0, new Intent(isWorking ? ACTION_PAUSE_SCAN : ACTION_RESUME_SCAN), PendingIntent.FLAG_UPDATE_CURRENT);
-                    NotificationCompat.Action playpause = isWorking ? new NotificationCompat.Action(R.drawable.ic_pause, getString(R.string.pause), pi)
-                            : new NotificationCompat.Action(R.drawable.ic_play, getString(R.string.resume), pi);
+                if (wasWorking != mMedialibrary.isWorking()) {
+                    wasWorking = !wasWorking;
+                    notificationIntent.setAction(mScanPaused ? ACTION_RESUME_SCAN : ACTION_PAUSE_SCAN);
+                    PendingIntent pi = PendingIntent.getBroadcast(VLCApplication.getAppContext(), 0, notificationIntent, PendingIntent.FLAG_UPDATE_CURRENT);
+                    NotificationCompat.Action playpause = mScanPaused ? new NotificationCompat.Action(R.drawable.ic_play, getString(R.string.resume), pi)
+                            : new NotificationCompat.Action(R.drawable.ic_pause, getString(R.string.pause), pi);
                     builder.mActions.clear();
                     builder.addAction(playpause);
                 }
                 final Notification notification = builder.build();
                 synchronized (MediaParsingService.this) {
                     if (mLastNotificationTime != -1L) {
+                        mLocalBroadcastManager.sendBroadcast(progessIntent
+                                .putExtra(ACTION_PROGRESS_TEXT, progressText)
+                                .putExtra(ACTION_PROGRESS_VALUE, mParsing));
                         try {
-                            NotificationManagerCompat.from(MediaParsingService.this).notify(43, notification);
+                            startForeground(43, notification);
                         } catch (IllegalArgumentException ignored) {}
                     }
                 }
@@ -269,7 +296,7 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
     }
 
     private void hideNotification() {
-        synchronized (this) {
+        synchronized (MediaParsingService.this) {
             mLastNotificationTime = -1L;
             NotificationManagerCompat.from(MediaParsingService.this).cancel(43);
         }
@@ -290,17 +317,13 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
     @Override
     public void onDiscoveryCompleted(String entryPoint) {
         if (BuildConfig.DEBUG) Log.d(TAG, "onDiscoveryCompleted: "+entryPoint);
-        if (!initOngoing && !mMedialibrary.isWorking())
-            stopSelf();
     }
 
     @Override
     public void onParsingStatsUpdated(int percent) {
         if (BuildConfig.DEBUG) Log.d(TAG, "onParsingStatsUpdated: "+percent);
         mParsing = percent;
-        if (mParsing == 100)
-            stopSelf();
-        else
+        if (mParsing != 100)
             showNotification();
     }
 
@@ -316,16 +339,15 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
         if (BuildConfig.DEBUG) Log.d(TAG, "onReloadCompleted "+entryPoint);
         if (TextUtils.isEmpty(entryPoint))
             --mReload;
-        if (!initOngoing && !mMedialibrary.isWorking())
-            stopSelf();
     }
 
     @Override
     public void onDestroy() {
-        LocalBroadcastManager.getInstance(this).sendBroadcast(new Intent(ACTION_SERVICE_ENDED));
+        mLocalBroadcastManager.sendBroadcast(new Intent(ACTION_SERVICE_ENDED));
         hideNotification();
         mMedialibrary.removeDeviceDiscoveryCb(this);
         unregisterReceiver(mReceiver);
+        mLocalBroadcastManager.unregisterReceiver(mReceiver);
         if (mWakeLock.isHeld())
             mWakeLock.release();
         super.onDestroy();
