@@ -85,39 +85,41 @@ public class VLCApplication extends Application {
 
     @Override
     public void onCreate() {
-        super.onCreate();
+        synchronized (getClass()) {
+            super.onCreate();
 
-        // Are we using advanced debugging - locale?
-        mSettings = PreferenceManager.getDefaultSharedPreferences(this);
-        String p = mSettings.getString("set_locale", "");
-        if (!p.equals("")) {
-            Locale locale;
-            // workaround due to region code
-            if(p.equals("zh-TW")) {
-                locale = Locale.TRADITIONAL_CHINESE;
-            } else if(p.startsWith("zh")) {
-                locale = Locale.CHINA;
-            } else if(p.equals("pt-BR")) {
-                locale = new Locale("pt", "BR");
-            } else if(p.equals("bn-IN") || p.startsWith("bn")) {
-                locale = new Locale("bn", "IN");
-            } else {
-                /**
-                 * Avoid a crash of
-                 * java.lang.AssertionError: couldn't initialize LocaleData for locale
-                 * if the user enters nonsensical region codes.
-                 */
-                if(p.contains("-"))
-                    p = p.substring(0, p.indexOf('-'));
-                locale = new Locale(p);
+            // Are we using advanced debugging - locale?
+            mSettings = PreferenceManager.getDefaultSharedPreferences(this);
+            String p = mSettings.getString("set_locale", "");
+            if (!p.equals("")) {
+                Locale locale;
+                // workaround due to region code
+                if(p.equals("zh-TW")) {
+                    locale = Locale.TRADITIONAL_CHINESE;
+                } else if(p.startsWith("zh")) {
+                    locale = Locale.CHINA;
+                } else if(p.equals("pt-BR")) {
+                    locale = new Locale("pt", "BR");
+                } else if(p.equals("bn-IN") || p.startsWith("bn")) {
+                    locale = new Locale("bn", "IN");
+                } else {
+                    /**
+                     * Avoid a crash of
+                     * java.lang.AssertionError: couldn't initialize LocaleData for locale
+                     * if the user enters nonsensical region codes.
+                     */
+                    if(p.contains("-"))
+                        p = p.substring(0, p.indexOf('-'));
+                    locale = new Locale(p);
+                }
+                Locale.setDefault(locale);
+                Configuration config = new Configuration();
+                config.locale = locale;
+                getResources().updateConfiguration(config,
+                        getResources().getDisplayMetrics());
             }
-            Locale.setDefault(locale);
-            Configuration config = new Configuration();
-            config.locale = locale;
-            getResources().updateConfiguration(config,
-                    getResources().getDisplayMetrics());
+            instance = this;
         }
-        instance = this;
 
         runBackground(new Runnable() {
             @Override
@@ -160,7 +162,7 @@ public class VLCApplication extends Application {
     /**
      * @return the main context of the Application
      */
-    public static Context getAppContext()
+    public static synchronized Context getAppContext()
     {
         return instance;
     }
@@ -248,7 +250,7 @@ public class VLCApplication extends Application {
     public static synchronized Medialibrary getMLInstance() {
         if (sMedialibraryInstance == null) {
             VLCInstance.get(); // ensure VLC is loaded before medialibrary
-            sMedialibraryInstance = Medialibrary.getInstance();
+            sMedialibraryInstance = Medialibrary.getInstance(instance);
         }
         return sMedialibraryInstance;
     }
